@@ -44,7 +44,7 @@ AWS_REGION = check_required_setting(
     "CHUNK_UPLOADER_AWS_REGION",
     "AWS_REGION",
 )
-S3_ENDPOINT_URL = getattr(settings, "S3_ENDPOINT_URL", None)
+AWS_S3_ENDPOINT_URL = getattr(settings, "AWS_S3_ENDPOINT_URL", None)
 S3_ROOT_DIRECTORY = getattr(settings, "CHUNK_UPLOADER_S3_ROOT_DIRECTORY", "")
 
 S3_MIN_PART_SIZE = 5 * 1024 * 1024
@@ -137,8 +137,8 @@ class S3FileUploadHandler(FileUploadHandler):
         self.new_file_name = f"{S3_ROOT_DIRECTORY}{self.file_name.replace(extension, '')}_{time_stamp}{extension}"
 
         extra_kwargs = {}
-        if S3_ENDPOINT_URL:
-            extra_kwargs['endpoint_url'] = S3_ENDPOINT_URL
+        if AWS_S3_ENDPOINT_URL:
+            extra_kwargs['endpoint_url'] = AWS_S3_ENDPOINT_URL
 
         self.s3_client = boto3_client(
             "s3",
